@@ -305,13 +305,6 @@ class EngagementRateFB:
         try:
             df_eng_by_day = deepcopy(df_posts_full)
             df_post_by_date = df_eng_by_day
-            df_post_by_date = df_post_by_date[["date", "post_id"]]
-            df_post_by_date = (
-                df_post_by_date.groupby("date")["post_id"]
-                .apply(list)
-                .reset_index(name="list_id_post")
-            )
-            df_post_by_date = df_post_by_date.list_id_post
             df_eng_by_day = (
                 df_eng_by_day[
                     [
@@ -364,6 +357,7 @@ class EngagementRateFB:
                 / row.fan_count,
                 axis=1,
             )
+
             df_eng_by_day = df_eng_by_day.reset_index()
 
             if grouped:
@@ -375,20 +369,48 @@ class EngagementRateFB:
                 df_eng_by_day = df_eng_by_day.reset_index()
                 PAGE_COLUMNS = []
                 ITEM_COLUMN = "group"
+                df_post_by_date = df_post_by_date.reset_index()
+                df_eng_by_day["list_posts"] = ""
+                # pdb.set_trace()
+                for i in range(0, len(df_eng_by_day)):
+                    date = df_eng_by_day["date"][i]
+                    group = df_eng_by_day["group"][i]
+                    list_post_id = []
+                    for j in range(0, len(df_post_by_date)):
+                        if date == df_post_by_date["date"][j]:
+                            if group == df_post_by_date["group"][j]:
+                                list_post_id.append(df_post_by_date["post_id"][j])
+                    df_eng_by_day["list_posts"][i] = list_post_id
+                    df_eng_by_day["list_posts"][i] = list(
+                        set(df_eng_by_day["list_posts"][i])
+                    )
+
             else:
                 df_eng_by_day = df_eng_by_day.rename(
                     columns={"page_id": "_object_id", "page_name": "_object_name"}
                 )
                 PAGE_COLUMNS = ["_object_id", "_object_name"]
                 ITEM_COLUMN = "_object_id"
+                df_post_by_date = df_post_by_date.reset_index()
+                df_eng_by_day["list_posts"] = ""
+                for i in range(0, len(df_eng_by_day)):
+                    date = df_eng_by_day["date"][i]
+                    object_id = df_eng_by_day["_object_id"][i]
+                    list_post_id = []
+                    for j in range(0, len(df_post_by_date)):
+                        if date == df_post_by_date["date"][j]:
+                            if object_id == df_post_by_date["page_id"][j]:
+                                list_post_id.append(df_post_by_date["post_id"][j])
+                    df_eng_by_day["list_posts"][i] = list_post_id
+                    df_eng_by_day["list_posts"][i] = list(
+                        set(df_eng_by_day["list_posts"][i])
+                    )
 
             METRIC = "engagement_rate_by_day"
             df_eng_by_day = df_eng_by_day.sort_values(by=["date"])
             df_eng_by_day = metric_transformation.MetricCategorization(
                 df_eng_by_day, METRIC, ITEM_COLUMN
             ).categorize()
-
-            df_eng_by_day["list_post_id"] = df_post_by_date
             return df_eng_by_day[
                 PAGE_COLUMNS
                 + [
@@ -397,7 +419,7 @@ class EngagementRateFB:
                     "boundary",
                     "rel_engagement_rate_by_day",
                     "engagement_rate_by_day",
-                    "list_post_id",
+                    "list_posts",
                 ]
             ].dropna(subset=["engagement_rate_by_day"])
 
@@ -413,8 +435,6 @@ class EngagementRateFB:
                     "group",
                     "date",
                     "engagement_rate_by_day",
-                    "boundary",
-                    "rel_engagement_rate_by_day",
                 ]
             )
 
