@@ -26,6 +26,7 @@ class STTMgroupsFB:
     """
 
     def __init__(self, df_comments, df_pages, account_ids=[], account_names=[]):
+
         """
         This method computes the DataFrame 'df_comments_full'
         which contains all the information of the comments, including columns 'page_name' and 'group'.
@@ -41,10 +42,12 @@ class STTMgroupsFB:
             Information of the pages.
             This Pandas DataFrame must have columns 'page_id' and 'name'.
             It is used just to set the page name in the DataFrame 'df_comments'. That page name corresponds of the page of the post to which the comment is asociated.
-        groups:
-            type: dict
-            Maps the groups (client, competition, archetype, trends) to the
-            corresponding page ids for each group.
+        account_ids=[]:
+            type: list
+            list of accounts ids in case filtering by account id is needed.
+        account_names=[]:
+            type: list
+            list of accounts names in case filtering by account name is needed.
         """
 
         METHOD_NAME = "__init__"
@@ -103,6 +106,23 @@ class STTMgroupsFB:
             self.df_comments_full = pd.DataFrame(columns=[""])
 
     def remove_from_text(self, text, toremove):
+        """
+        removes words from text.
+
+        Parameters
+        ----------
+        text
+            type: list of strings
+            text of the post or comment.
+
+        toremove:
+            type: list of strings
+            list of words to remove from text.
+
+        Returns
+        -------
+        list of strings
+        """
         text_copy = deepcopy(text)
         for word in text:
             if word in toremove:
@@ -110,6 +130,29 @@ class STTMgroupsFB:
         return text_copy
 
     def get_sttm_groups(self, with_remove=False, list_remove=[], min_texts=100):
+        """
+        Uses Short Text Topic Modelling to group the texts.
+        Returns the input DataFrame with an additional column (sttm_group) with the group number to which each text was assigned.
+
+        Parameters
+        ----------
+        with_remove (optional, default False)
+            type: boolean
+            set to True if user wants to remove a list of words from the texts before grouping.
+
+        list_remove
+            type: list
+            list of words that the user wants to remove
+
+        min_texts
+            type: int
+            minimum number of texts in the DataFrame (after cleaning and dropping empty texts) that is required to proceed with the sttm analysis.
+
+        Returns
+        -------
+        DataFrame with an additional column (sttm_groups)
+        """
+
         METHOD_NAME = "get_sttm_groups"
 
         try:
@@ -135,7 +178,6 @@ class STTMgroupsFB:
             )
 
             if list_remove:
-                # self.df_comments_full['processed_text'] = self.df_comments_full['processed_text'].apply(lambda x: json.loads(x))
                 self.df_comments_full["processed_text"] = self.df_comments_full[
                     "processed_text"
                 ].apply(lambda x: str(x).split(" "))
@@ -215,11 +257,33 @@ class STTMgroupsFB:
     def get_sttm_groups_withremove(
         self, df_preprocessed_sttm, list_toremove=[], min_texts=100
     ):
+        """
+        Uses Short Text Topic Modelling to group the texts.
+        Returns the input DataFrame with an additional column (sttm_group) with the group number to which each text was assigned.
+
+        Parameters
+        ----------
+        df_preprocessed_sttm
+            type: DataFrame
+            Preprocessed DataFrame so that the grouping can be redone without redoing the tokenizing of the text..
+
+        list_toremove
+            type: list
+            list of words that the user wants to remove.
+
+        min_texts
+            type: int
+            minimum number of texts in the DataFrame (after cleaning and dropping empty texts) that is required to proceed with the sttm analysis.
+
+        Returns
+        -------
+        DataFrame with column (sttm_groups)
+        """
+
         METHOD_NAME = "get_sttm_groups_withremove"
         self.df_preprocessed_sttm = deepcopy(df_preprocessed_sttm)
 
         try:
-            # self.df_preprocessed_sttm['tokenized_text'] = self.df_preprocessed_sttm['tokenized_text'].apply(lambda x: json.loads(x))
             self.df_preprocessed_sttm["tokenized_text"] = self.df_preprocessed_sttm[
                 "tokenized_text"
             ].apply(lambda x: x[2:-2])
@@ -357,6 +421,147 @@ class STTMgroupsFB:
         ]
         self.data_texts = data_texts
 
+    def remove_insignificant_groups(
+        self,
+        df_sttm_groups,
+        min_num_docs=15,
+        min_group_percent=10,
+        max_num_groups=5,
+        min_num_groups=2,
+    ):
+
+        """
+        this function removes the groups that have very little relevance due to the small number of elements (comments) or the small percentage that they represent.
+
+        Parameters
+        ----------
+        df_sttm_groups:
+            type: DataFrame
+            DataFrame containing the comments and the group they belong to.
+
+        min_num_docs:
+            type:int
+            minimum number of comments that a group has to have in order to be show in the platform.
+
+        min_group_percent:
+            type: float
+            percentage threshold that a group has to represent in order to be show in the platform.
+
+        max_num_groups:
+            type:int
+            maximun number of groups shown by the platform.
+
+        min_num_groups:
+            type:int
+            minimum number of groups shown by the platform.
+
+        Returns
+        -------
+        DataFrame with only the groups that comply with the criteria.
+        """
+        METHOD_NAME = "remove_insignificant_groups"
+        if min_num_groups > max_num_groups:
+            min_num_groups = max_num_groups
+
+        if df_sttm_groups.shape[0] < min_num_groups:
+            min_num_groups = df_sttm_groups.shape[0]
+            max_num_groups = df_sttm_groups.shape[0]
+
+        try:
+            if (
+                df_sttm_groups["__n_docs"][min_num_groups - 1] <= min_num_docs
+                or df_sttm_groups["__percentage"][min_num_groups - 1]
+                <= min_group_percent
+            ):
+                df_sttm_groups = df_sttm_groups.head(min_num_groups)
+
+            else:
+                df_sttm_groups = df_sttm_groups[
+                    df_sttm_groups["__n_docs"] >= min_num_docs
+                ]
+
+                df_sttm_groups = df_sttm_groups[
+                    df_sttm_groups["__percentage"] >= min_group_percent
+                ]
+
+                df_sttm_groups = df_sttm_groups.head(max_num_groups)
+
+        except Exception as e:
+            print(e)
+            error_1 = sys.exc_info()[0]
+            print(ERR_SYS + str(error_1))
+            print(f"Class: {self.__str__()}\nMethod: {METHOD_NAME}")
+
+        return df_sttm_groups
+
+    def get_examples_from_sttm_groups(
+        self,
+        df_data_grouped,
+        group,
+        num_examples=3,
+        num_top_words_group=5,
+        min_text_lenght=1,
+    ):
+        """
+        this function returns examples of comments in each sttm group.
+
+        Parameters
+        ----------
+
+        df_data_grouped:
+            type: pandas DataFrame
+            max number ofDataFrame with grouped information for each sttm group.
+
+        group:
+            type:int
+            group number.
+
+        num_examples: (optional, default=3)
+            type:int
+            number of examples selected for each sttm group.
+
+        num_top_words_group: (optional, default=5)
+            type:int
+            number of most frequent words for each group that will be used as a selection crtiteria to decide wether or not a comment will be used as an example comment for the group.
+
+        min_text_lenght: (optional, default=1)
+            type:int
+            minimum number of tokens in the selected comment examples.
+
+        Returns
+        -------
+        a list of IDs of the selected example comments
+        """
+
+        df_comments = deepcopy(self.df_comments_full)
+        post_examples_id = []
+
+        group_word_list = [
+            *df_data_grouped[df_data_grouped["sttm_group"] == group]["__words"].iloc[0]
+        ]
+        num_top_words_group = min(num_top_words_group, len(group_word_list))
+
+        num_examples = min(
+            num_examples, df_comments[df_comments["sttm_group"] == group].shape[0]
+        )
+        group_word_list = group_word_list[:num_top_words_group]
+
+        df_comments["len_comments"] = df_comments.tokenized_text.apply(lambda x: len(x))
+        df_comments["word_in_comment"] = df_comments.tokenized_text.apply(
+            lambda x: True if (set(x) & set(group_word_list)) else False
+        )
+        df_sample = df_comments.where(
+            (df_comments["len_comments"] >= min_text_lenght)
+            & (df_comments["word_in_comment"] == True)
+        )
+        df_sample = df_sample.dropna(subset=["len_comments", "word_in_comment"])
+
+        if df_sample.shape[0] > num_examples:
+            post_examples_id = df_sample.message.sample(num_examples).values.tolist()
+        else:
+            post_examples_id = df_sample.message.values.tolist()
+        return post_examples_id
+
     def get_grouped_dataframe(self):
         """
         Groups the DataFrame 'data' into a DataFrame containing information
@@ -420,8 +625,13 @@ class STTMgroupsFB:
         data_grouped["__words"] = data_grouped.apply(
             lambda row: self.counter_of_words(row["__words"], row["__mention"]), axis=1
         )
-        data_grouped = data_grouped.drop(columns=["__mention"])
 
+        data_grouped = data_grouped.reset_index().sort_values(
+            "__percentage", ascending=False
+        )
+        data_grouped = self.remove_insignificant_groups(data_grouped)
+
+        data_grouped = data_grouped.drop(columns=["__mention"])
         data_grouped["__weekday"] = data_grouped["__weekday"].apply(
             lambda wd: wd.split(",")
         )
@@ -440,8 +650,17 @@ class STTMgroupsFB:
             "__polarity_distribution"
         ].apply(lambda p: self.get_percentage(p))
 
-        data_grouped = data_grouped.reset_index().sort_values(
-            "__percentage", ascending=False
+        data_grouped["__examples_comments"] = data_grouped.sttm_group.apply(
+            lambda g: self.get_examples_from_sttm_groups(
+                data_grouped, g, num_examples=3
+            )
         )
 
+        # reorganize and rename sttm groups
+        data_grouped = data_grouped.reset_index()
+        data_grouped["sttm_group"] = data_grouped.index
+        data_grouped["sttm_group"] = data_grouped["sttm_group"].apply(lambda i: i + 1)
+        data_grouped = data_grouped.drop(columns="index")
+        self.data_grouped = data_grouped
+
         return data_grouped
