@@ -51,6 +51,7 @@ class EngagementRateIG:
                 "typename",
                 "caption_mentions",
                 "caption",
+                "mediaid",
             ]
             OUTPUT_COLUMNS = [
                 "followers",
@@ -320,20 +321,11 @@ class EngagementRateIG:
         PAGE_COLUMNS = []
         if not grouped:
             PAGE_COLUMNS = ["owner_id", "owner_username"]
-
         df_posts_full = self.df_posts_full
+
         try:
             df_eng_by_day = deepcopy(df_posts_full)
-
             df_post_by_date = df_eng_by_day
-            df_post_by_date = df_post_by_date[["date", "mediaid"]]
-            df_post_by_date = (
-                df_post_by_date.groupby("date")["mediaid"]
-                .apply(list)
-                .reset_index(name="list_id_post")
-            )
-            df_post_by_date = df_post_by_date.list_id_post
-
             df_eng_by_day = (
                 df_eng_by_day[
                     [
@@ -368,23 +360,53 @@ class EngagementRateIG:
                     .groupby(["group", "date"])
                     .mean()
                 )
-                df_eng_by_day = df_eng_by_day.reset_index()
+
                 PAGE_COLUMNS = []
                 ITEM_COLUMN = "group"
+                df_eng_by_day = df_eng_by_day.reset_index()
+                df_post_by_date = df_post_by_date.reset_index()
+                df_eng_by_day["list_posts"] = ""
+                # pdb.set_trace()
+                for i in range(0, len(df_eng_by_day)):
+                    date = df_eng_by_day["date"][i]
+                    group = df_eng_by_day["group"][i]
+                    list_post_id = []
+                    for j in range(0, len(df_post_by_date)):
+                        if date == df_post_by_date["date"][j]:
+                            if group == df_post_by_date["group"][j]:
+                                list_post_id.append(df_post_by_date["shortcode"][j])
+                    df_eng_by_day["list_posts"][i] = list_post_id
+                    df_eng_by_day["list_posts"][i] = list(
+                        set(df_eng_by_day["list_posts"][i])
+                    )
+
             else:
                 df_eng_by_day = df_eng_by_day.rename(
                     columns={"owner_id": "_object_id", "owner_username": "_object_name"}
                 )
                 PAGE_COLUMNS = ["_object_id", "_object_name"]
                 ITEM_COLUMN = "_object_id"
+                df_post_by_date = df_post_by_date.reset_index()
+                df_eng_by_day["list_posts"] = ""
+                for i in range(0, len(df_eng_by_day)):
+                    date = df_eng_by_day["date"][i]
+                    object_id = df_eng_by_day["_object_id"][i]
+                    list_post_id = []
+                    for j in range(0, len(df_post_by_date)):
+                        if date == df_post_by_date["date"][j]:
+                            if object_id == df_post_by_date["owner_id"][j]:
+                                list_post_id.append(df_post_by_date["shortcode"][j])
+                    df_eng_by_day["list_posts"][i] = list_post_id
+                    df_eng_by_day["list_posts"][i] = list(
+                        set(df_eng_by_day["list_posts"][i])
+                    )
 
             METRIC = "engagement_rate_by_day"
             df_eng_by_day = df_eng_by_day.sort_values(by=["date"])
             df_eng_by_day = metric_transformation.MetricCategorization(
                 df_eng_by_day, METRIC, ITEM_COLUMN
             ).categorize()
-            df_eng_by_day["list_post_id"] = df_post_by_date
-
+            # df_eng_by_day['list_post_id'] = df_post_by_date
             return df_eng_by_day[
                 PAGE_COLUMNS
                 + [
@@ -393,7 +415,7 @@ class EngagementRateIG:
                     "engagement_rate_by_day",
                     "boundary",
                     "rel_engagement_rate_by_day",
-                    "list_post_id",
+                    "list_posts",
                 ]
             ].dropna(subset=["engagement_rate_by_day"])
 
