@@ -127,7 +127,9 @@ class PolarityAnalysisIG:
                         }
                         for dict_values in df_date["sentiment"]:
                             for key in np.arange(-1.0, 1.5, 0.5):
-                                day_sentiment[key] += dict_values[key]
+                                day_sentiment[key] += (
+                                    dict_values[key] if key in dict_values else 0
+                                )
                         df_timeaccount.loc[len(df_timeaccount)] = [
                             brand_id,
                             page_names[brand_id],
@@ -202,6 +204,11 @@ class PolarityAnalysisIG:
             self.df_sentiment[0.5] = positive_05
             self.df_sentiment[1.0] = positive_1
             self.df_sentiment["count_comments"] = 1
+            self.df_sentiment[-1.0] = self.df_sentiment[-1.0].astype(float)
+            self.df_sentiment[-0.5] = self.df_sentiment[-0.5].astype(float)
+            self.df_sentiment[0.0] = self.df_sentiment[-0.0].astype(float)
+            self.df_sentiment[0.5] = self.df_sentiment[0.5].astype(float)
+            self.df_sentiment[1.0] = self.df_sentiment[1.0].astype(float)
             grouped = self.df_sentiment.groupby(["group", "date"], as_index=False).agg(
                 {
                     -1.0: "mean",
